@@ -464,7 +464,7 @@ void FormMain::switchVisibility(bool force_hide) {
 
 void FormMain::display() {
   // Make sure window is not minimized.
-  setWindowState(windowState() & ~Qt::WindowMinimized& ~Qt::WindowActive);
+  setWindowState((windowState() & ~Qt::WindowState::WindowMinimized) | Qt::WindowState::WindowActive);
 
   // Display the window and make sure it is raised on top.
   show();
